##  Which SAP LeanIX Products are Needed for Obsolescence Risk Management?
The following SAP LeanIX products help you assess your application portfolio, build a technology inventory, and identify, address, and monitor obsolescence risk management efforts:
  * [SAP LeanIX Application Portfolio Management](https://help.sap.com/docs/leanix/ea/onboarding-guide-application-portfolio-management?locale=en-US&state=PRODUCTION&version=CLOUD "The onboarding guide offers a streamlined onboarding process for SAP LeanIX Application Portfolio Management, providing step-by-step instructions, resources, and progress tracking.") is the base product necessary for building a comprehensive inventory of your IT landscape. With Application Portfolio Management you establish relationships among all necessary architectural elements to understand dependencies and structure within IT and business. It enables you to analyze and assess the business criticality, functional, and technical fit of applications, aiding in the prioritization of risks. Using various predefined reports, you can effectively monitor the application landscape for emerging obsolescence risks. SAP LeanIX Technology Risk and Compliance further enriches obsolescence risk management efforts by providing specific, powerful functionalities.
  * [SAP LeanIX Technology Risk and Compliance](https://help.sap.com/docs/leanix/ea/tutorial-managing-it-risks-associated-with-data-center-and-server-locations?locale=en-US&state=PRODUCTION&version=CLOUD "This is an example tutorial on managing the impact of data center and server location on risk mitigation and compliance using SAP LeanIX Technology Risk and Compliance.") helps you build your technology inventory, offers capabilities to proactively identify and assess current and future security risks caused by outdated components, and enables you to mitigate these risks effectively. Through integration with ServiceNow, the product automates the discovery of IT components and applications to build technology inventory swiftly. Furthermore, for IT components, the product provides access to lifecycle information from the reference catalog, automating the retrieval of lifecycle and end-of-support details. Additional obsolescence risk management views in reports and dedicated obsolescence risk management dashboard help you to plan, prioritize actions, and monitor identified risks that need to be addressed.
